SearchState

Struct SearchState 

pub struct SearchState {
    pub query: Option<String>,
    pub filtered_indices: Vec<usize>,
    pub filtered_pattern_indices: Vec<usize>,
    pub pre_search_selection: Option<usize>,
    pub scope_indices: Option<HashSet<usize>>,
}
Search mode state.

Fields

query: Option<String>filtered_indices: Vec<usize>filtered_pattern_indices: Vec<usize>pre_search_selection: Option<usize>scope_indices: Option<HashSet<usize>>

When a group tab is active, holds the host indices visible in that group. Search results are intersected with this set to scope the search.