pub struct SnippetForm {
pub name: String,
pub command: String,
pub description: String,
pub focused_field: SnippetFormField,
pub cursor_pos: usize,
}Expand description
Form state for adding/editing a snippet.
Fields
name: Stringcommand: Stringdescription: Stringfocused_field: SnippetFormFieldcursor_pos: usizeImplementations
Sourceimpl SnippetForm
impl SnippetForm
pub fn from_snippet(snippet: &Snippet) -> Self
Sourcepub fn focus_next(&mut self)
pub fn focus_next(&mut self)
Advance the focused field to the next one and sync the cursor to the end of the new focused value.
Sourcepub fn focus_prev(&mut self)
pub fn focus_prev(&mut self)
Retreat the focused field to the previous one and sync the cursor to the end of the new focused value.
pub fn focused_value(&self) -> &str
pub fn focused_value_mut(&mut self) -> &mut String
pub fn insert_char(&mut self, c: char)
pub fn delete_char_before_cursor(&mut self)
pub fn sync_cursor_to_end(&mut self)
pub fn validate(&self) -> Result<(), String>