pub struct ContainerListing {
pub runtime: ContainerRuntime,
pub engine_version: Option<String>,
pub containers: Vec<ContainerInfo>,
}Expand description
Parsed result of a container listing command. engine_version is the
daemon’s Server.Version (best-effort, None when the version sub-call
failed or the remote runtime predates the engine sentinel).
Fields
runtime: ContainerRuntimeengine_version: Option<String>containers: Vec<ContainerInfo>Trait Implementations
Sourceimpl Clone for ContainerListing
impl Clone for ContainerListing
Sourcefn clone(&self) -> ContainerListing
fn clone(&self) -> ContainerListing
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ContainerListing
impl Debug for ContainerListing
Sourceimpl PartialEq for ContainerListing
impl PartialEq for ContainerListing
Sourcefn eq(&self, other: &ContainerListing) -> bool
fn eq(&self, other: &ContainerListing) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ContainerListing