ping_all

Function ping_all 

pub fn ping_all(
    hosts: &[(String, String, u16)],
    tx: Sender<AppEvent>,
    generation: u64,
)
Ping all given hosts with a concurrency limit of 10. Spawns a coordinator thread that uses a semaphore-style channel to limit concurrent pings, preventing thread explosion on large host lists.