ThemeDef

Struct ThemeDef 

pub struct ThemeDef {
Show 17 fields pub name: String, pub accent: ColorSlot, pub accent_bg: ColorSlot, pub success: ColorSlot, pub success_dim: ColorSlot, pub warning: ColorSlot, pub error: ColorSlot, pub highlight: ColorSlot, pub border: ColorSlot, pub border_active: ColorSlot, pub fg_muted: ColorSlot, pub fg_bold: ColorSlot, pub footer_key: ColorSlot, pub badge: ColorSlot, pub selected_fg: ColorSlot, pub footer_key_fg: ColorSlot, pub logo_dot: ColorSlot,
}
Complete theme definition with all color slots.

Fields

name: Stringaccent: ColorSlotaccent_bg: ColorSlotsuccess: ColorSlotsuccess_dim: ColorSlotwarning: ColorSloterror: ColorSlothighlight: ColorSlotborder: ColorSlotborder_active: ColorSlotfg_muted: ColorSlotfg_bold: ColorSlotfooter_key: ColorSlotbadge: ColorSlotselected_fg: ColorSlotfooter_key_fg: ColorSlotlogo_dot: ColorSlot

Accent for the trailing . of the purple. logotype in overlay headers (Welcome, Help, What’s-New). Intentionally different from accent so the dot reads as a separate accent glyph — mirrors the landing-page hero where the dot is cyan over purple text.

Implementations

Source

impl ThemeDef

pub fn purple() -> Self

pub fn purple_purple() -> Self

pub fn catppuccin_mocha() -> Self

pub fn dracula() -> Self

pub fn gruvbox_dark() -> Self

pub fn nord() -> Self

pub fn tokyo_night() -> Self

pub fn one_dark() -> Self

pub fn catppuccin_latte() -> Self

pub fn solarized_light() -> Self

pub fn no_color() -> Self

pub fn builtins() -> Vec<ThemeDef>

pub fn find_builtin(name: &str) -> Option<ThemeDef>

pub fn parse_toml(content: &str) -> Option<Self>

pub fn load_custom() -> Vec<ThemeDef>