pub fn match_source_for_host(host: &HostHit, query: &str) -> Option<MatchSource>Expand description
Determine which field caused the host hit to match. The renderer uses
this to append a via user, via proxy, vault: <role> hint to the
row when the matched field is not part of the visible columns. Returns
None if the alias/hostname (already visible) matched.