pub struct UiSelection { /* private fields */ }Implementations
Sourceimpl UiSelection
impl UiSelection
Sourcepub fn new_with_initial_selection(initial: Option<usize>) -> Self
pub fn new_with_initial_selection(initial: Option<usize>) -> Self
Construct with all picker/list state defaulted and the host list
selection pre-positioned at initial (the first selectable host or
pattern in the display list).
Sourcepub fn queue_connect(&mut self, alias: String, askpass: Option<String>)
pub fn queue_connect(&mut self, alias: String, askpass: Option<String>)
Queue an SSH connect for the event loop to pick up via the next
pending_connect.take(). askpass carries the resolved per-host
password source so the event loop can prepare a SSH_ASKPASS env
before spawning the child.
Sourcepub fn open_snippet_search(&mut self)
pub fn open_snippet_search(&mut self)
Enter snippet picker search mode with an empty query.
Sourcepub fn close_snippet_search(&mut self)
pub fn close_snippet_search(&mut self)
Exit snippet picker search mode. Idempotent.
pub fn list_state(&self) -> &ListState
pub fn list_state_mut(&mut self) -> &mut ListState
pub fn key_picker(&self) -> &PickerState
pub fn key_picker_mut(&mut self) -> &mut PickerState
pub fn password_picker(&self) -> &PickerState
pub fn password_picker_mut(&mut self) -> &mut PickerState
pub fn proxyjump_picker(&self) -> &PickerState
pub fn proxyjump_picker_mut(&mut self) -> &mut PickerState
pub fn vault_role_picker(&self) -> &PickerState
pub fn vault_role_picker_mut(&mut self) -> &mut PickerState
pub fn tag_picker_state(&self) -> &ListState
pub fn tag_picker_state_mut(&mut self) -> &mut ListState
pub fn bulk_tag_editor_state(&self) -> &ListState
pub fn bulk_tag_editor_state_mut(&mut self) -> &mut ListState
pub fn theme_picker(&self) -> &ThemePickerState
pub fn theme_picker_mut(&mut self) -> &mut ThemePickerState
pub fn provider_list_state(&self) -> &ListState
pub fn provider_list_state_mut(&mut self) -> &mut ListState
pub fn tunnel_list_state(&self) -> &ListState
pub fn tunnel_list_state_mut(&mut self) -> &mut ListState
pub fn tunnels_overview_state(&self) -> &ListState
pub fn tunnels_overview_state_mut(&mut self) -> &mut ListState
pub fn containers_overview_state(&self) -> &ListState
pub fn containers_overview_state_mut(&mut self) -> &mut ListState
pub fn tunnel_host_picker_state(&self) -> &ListState
pub fn tunnel_host_picker_state_mut(&mut self) -> &mut ListState
pub fn tunnel_host_picker_query(&self) -> &String
pub fn tunnel_host_picker_query_mut(&mut self) -> &mut String
pub fn set_tunnel_host_picker_query(&mut self, query: String)
pub fn container_host_picker_state(&self) -> &ListState
pub fn container_host_picker_state_mut(&mut self) -> &mut ListState
pub fn container_host_picker_query(&self) -> &String
pub fn container_host_picker_query_mut(&mut self) -> &mut String
pub fn set_container_host_picker_query(&mut self, query: String)
pub fn snippet_picker_state(&self) -> &ListState
pub fn snippet_picker_state_mut(&mut self) -> &mut ListState
pub fn snippet_search(&self) -> Option<&String>
pub fn snippet_search_mut(&mut self) -> Option<&mut String>
pub fn region_picker(&self) -> &RegionPickerState
pub fn region_picker_mut(&mut self) -> &mut RegionPickerState
pub fn help_scroll(&self) -> u16
pub fn set_help_scroll(&mut self, scroll: u16)
pub fn detail_scroll(&self) -> u16
pub fn set_detail_scroll(&mut self, scroll: u16)
pub fn detail_toggle_pending(&self) -> bool
pub fn set_detail_toggle_pending(&mut self, pending: bool)
pub fn welcome_opened(&self) -> Option<Instant>
pub fn set_welcome_opened(&mut self, when: Option<Instant>)
pub fn esc_quit_hint_shown(&self) -> bool
pub fn set_esc_quit_hint_shown(&mut self, shown: bool)
pub fn known_hosts_count(&self) -> usize
pub fn set_known_hosts_count(&mut self, count: usize)
pub fn pending_connect(&self) -> Option<&(String, Option<String>)>