pub fn host_pattern_matches(host_pattern: &str, alias: &str) -> boolExpand description
Check whether a Host pattern matches a given alias.
OpenSSH Host keyword matches only against the target alias typed on the
command line, never against the resolved HostName.